From ed30c60150ffda0301eb1f8d30c93cac94de41df Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Mon, 25 Jul 2011 10:38:22 -0400
Subject: [PATCH] Fixed some warnings in the installer.
---
interface/web/sites/ftp_user_list.php | 36 ++++++++++++++++++++++++++----------
1 files changed, 26 insertions(+), 10 deletions(-)
diff --git a/interface/web/sites/ftp_user_list.php b/interface/web/sites/ftp_user_list.php
index 516739f..ef94dc2 100644
--- a/interface/web/sites/ftp_user_list.php
+++ b/interface/web/sites/ftp_user_list.php
@@ -41,18 +41,34 @@
* End Form configuration
******************************************/
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
- header("Location: ../index.php");
- exit;
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
+
+$app->load('listform_actions');
+
+
+class list_action extends listform_actions {
+
+ function onShow() {
+ global $app,$conf;
+
+ $app->uses('getconf');
+ $global_config = $app->getconf->get_global_config('sites');
+
+ if($global_config['webftp_url'] != '') {
+ $app->tpl->setVar('webftp_link',1);
+ $app->tpl->setVar('webftp_url',$global_config['webftp_url']);
+ } else {
+ $app->tpl->setVar('webftp_link',0);
+ }
+
+ parent::onShow();
+ }
+
}
-$app->uses('listform_actions');
-
-// Limit the results to alias domains
-//$app->listform_actions->SQLExtWhere = "type = 'subdomain'";
-
-$app->listform_actions->onLoad();
+$list = new list_action;
+$list->onLoad();
?>
\ No newline at end of file
--
Gitblit v1.9.1